Function core_affinity::set_for_current
source · Expand description
This function tries to pin the current thread to the specified core.
Arguments
- core_id - ID of the core to pin
This function tries to pin the current thread to the specified core.